Как установить TrueConf для Linux

Автор03.04.2024Дата написанияОколо 10 минВремя чтенияКлиентские приложенияКатегорияLinuxTrueConf SolutionsТеги

Как установить TrueConf для Linux

Пользователи ОС Linux могут полноценно участвовать в конференциях и поддерживать связь с коллегами благодаря клиентским приложениям TrueConf, доступным для всех популярных Linux дистрибутивов. Оцените преимущества TrueConf:

  • 4К видеоконференции до 2000 участников;

  • Групповые и личные чаты, каналы;

  • Группировка чатов по папкам, а также перемещение в архив;

  • Поддержка избранного (личного чата с важными сообщениями);

  • Запись конференций;

  • Захват контента и показ презентаций;

  • Удаленное управление рабочим столом;

  • Расширенное управление конференциями;

  • 100% безопасность ваших коммуникаций.

Узнайте версию своей ОС

Если вы не уверены, какая у вас версия операционной системы, то узнайте её с помощью следующей команды в терминале (она универсальна для всех ОС семейства Linux):

cat /etc/*release*

В консоли выведутся основные сведения об ОС, среди которых будет её название и версия. На примере ниже показан скриншот таких данных, из которых следует, что установлена РЕД ОС 7.3.1:

/blog/baza-znaniy/media/trueconf-linux/debian-10-info/ru.png

Скачайте приложение TrueConf для Linux

Выберите вашу операционную систему

В случае возникновения проблем при установке приложения, пожалуйста, обратитесь в службу поддержки.

Графическая установка

Для установки TrueConf мы рекомендуем использовать графический установщик, который можно запустить (двойным) кликом по скачанному пакету или через контекстное меню. Например, в Ubuntu: Открыть с помощью "Центр приложений Ubuntu".

Для установки из терминала команды требуется выполнять с использованием sudo, или предварительно перейти в режим администратора, выполнив в терминале команду su - и введя root-пароль. Учтите, что по умолчанию sudo может отсутствовать в ОС, проверить его наличие можно командой sudo -V. Показанные далее примеры используют sudo.

Debian, Ubuntu, Mint, Astra Linux

Как установить?

Используя учетную запись администратора, нужно запустить команду для скачанного пакета.

sudo apt install ./trueconf_client_name.deb

где trueconf_client_name.deb — название скачанного пакета.

После установки приложения адрес репозитория TrueConf пропишется автоматически.

Перед установкой приложения на Astra Linux SE 1.6 (Смоленск), нужно “примонтировать” DVD диск, идущий в комплекте с ОС Astra Linux с дополнительными библиотеками, в качестве репозитория и выполнить команду

sudo apt update

Альтернативный вариант установки

Под учётной записью администратора выполните следующие команды в терминале (консоли):

  • Debian 12 и старше

    • Выполните следующую команду, чтобы создать файл /etc/apt/sources.list.d/trueconf.list сразу с нужным содержимым внутри:

      echo "deb [arch=$(dpkg --print-architecture)] https://mirror.trueconf.ru/debian $(lsb_release -cs) non-free" | sudo tee /etc/apt/sources.list.d/trueconf.list > /dev/null
    • С помощью учетной записи администратора последовательно выполните команды:

      wget -O- https://mirror.trueconf.ru/deb.trueconf.asc | sudo gpg --no-default-keyring --keyring gnupg-ring:/etc/apt/trusted.gpg.d/trueconf.gpg --import
      sudo chmod 644 /etc/apt/trusted.gpg.d/trueconf.gpg
      sudo apt -y update
      sudo apt -y install trueconf
  • Debian 13+

    • Выполните следующую команду, чтобы создать файл /etc/apt/sources.list.d/trueconf.sources сразу с нужным содержимым внутри:

      echo "Types: deb
      URIs: https://mirror.trueconf.ru/debian
      Suites: $(lsb_release -cs)
      Components: non-free
      Signed-By: /usr/share/keyrings/trueconf.gpg
      " | sudo tee /etc/apt/sources.list.d/trueconf.sources > /dev/null
    • С помощью учетной записи администратора последовательно выполните команды для установки ключа:

      wget -O- https://mirror.trueconf.ru/deb.trueconf.asc | sudo gpg --no-default-keyring --keyring gnupg-ring:/usr/share/keyrings/trueconf.gpg --import
      sudo chmod 644 /usr/share/keyrings/trueconf.gpg

      ВНИМАНИЕ! Если вы ранее устанавливали приложение Труконф из репозитория используя ключ .pub (или видите ошибку проверки публичного ключа), то сначала требуется удалить старый ключ с помощью команды:

      sudo rm /etc/apt/trusted.gpg.d/trueconf.gpg

      И повторить процедуру установки ключа.

    • Теперь обновите информацию о пакетах и установите приложение:

      sudo apt update
      sudo apt install trueconf
  • Ubuntu 22.10+

    • Выполните следующую команду, чтобы создать файл /etc/apt/sources.list.d/trueconf.sources сразу с нужным содержимым внутри:

      echo "Types: deb
      URIs: https://mirror.trueconf.ru/ubuntu
      Suites: $(lsb_release -cs)
      Components: non-free
      Signed-By: /usr/share/keyrings/trueconf.gpg
      " | sudo tee /etc/apt/sources.list.d/trueconf.sources > /dev/null
    • С помощью учетной записи администратора последовательно выполните команды установки ключа:

      wget -O- https://mirror.trueconf.ru/deb.trueconf.asc | sudo gpg --no-default-keyring --keyring gnupg-ring:/usr/share/keyrings/trueconf.gpg --import
      sudo chmod 644 /usr/share/keyrings/trueconf.gpg

      ВНИМАНИЕ! Если вы ранее устанавливали приложение Труконф из репозитория используя ключ .pub (или видите ошибку проверки публичного ключа), то сначала требуется удалить старый ключ с помощью команды:

      sudo rm /etc/apt/trusted.gpg.d/trueconf.gpg

      И повторить процедуру установки ключа.

    • Теперь обновите информацию о пакетах и установите приложение:

      sudo apt update
      sudo apt install trueconf
  • Linux Mint

    • Выполните следующую команду, чтобы создать файл /etc/apt/sources.list.d/trueconf.sources сразу с нужным содержимым внутри:

      echo "deb [arch=$(dpkg --print-architecture)] https://mirror.trueconf.ru/ubuntu $(lsb_release -cs) non-free" | sudo tee /etc/apt/sources.list.d/trueconf.list > /dev/null
      wget -O- https://mirror.trueconf.ru/deb.trueconf.asc | sudo gpg --no-default-keyring --keyring gnupg-ring:/etc/apt/trusted.gpg.d/trueconf.gpg --import
      sudo chmod 644 /etc/apt/trusted.gpg.d/trueconf.gpg
      sudo apt -y update
      sudo apt -y install trueconf
    • С помощью учетной записи администратора последовательно выполните команды установки ключа:

      wget -O- https://mirror.trueconf.ru/deb.trueconf.asc | sudo gpg --no-default-keyring --keyring gnupg-ring:/usr/share/keyrings/trueconf.gpg --import
      sudo chmod 644 /usr/share/keyrings/trueconf.gpg

      ВНИМАНИЕ! Если вы ранее устанавливали приложение Труконф из репозитория используя ключ .pub (или видите ошибку проверки публичного ключа), то сначала требуется удалить старый ключ с помощью команды:

      sudo rm /etc/apt/trusted.gpg.d/trueconf.gpg

      И повторить процедуру установки ключа.

    • Теперь обновите информацию о пакетах и установите приложение:

      sudo apt -y update
      sudo apt install trueconf
  • Ubuntu 22.04 и старее

    echo "deb [arch=$(dpkg --print-architecture)] https://mirror.trueconf.ru/ubuntu $(lsb_release -cs) non-free" | sudo tee /etc/apt/sources.list.d/trueconf.list > /dev/null
    wget -O- https://mirror.trueconf.ru/deb.trueconf.asc | sudo gpg --no-default-keyring --keyring gnupg-ring:/etc/apt/trusted.gpg.d/trueconf.gpg --import
    sudo chmod 644 /etc/apt/trusted.gpg.d/trueconf.gpg
    sudo apt -y update
    sudo apt -y install trueconf
  • Для Astra Linux Special Edition 1.8, 1.7, 1.6

    echo "deb [arch=$(dpkg --print-architecture)] https://mirror.trueconf.ru/astra $(lsb_release -cs) non-free" | sudo tee /etc/apt/sources.list.d/trueconf.list > /dev/null
    wget -O- https://mirror.trueconf.ru/deb.trueconf.asc | sudo gpg --no-default-keyring --keyring gnupg-ring:/etc/apt/trusted.gpg.d/trueconf.gpg --import
    sudo chmod 644 /etc/apt/trusted.gpg.d/trueconf.gpg
    sudo apt -y update
    sudo apt -y install trueconf
  • Для Astra Linux Common Edition 2.12

    echo "deb [arch=$(dpkg --print-architecture)] https://mirror.trueconf.ru/astra212 $(lsb_release -cs) non-free" | sudo tee /etc/apt/sources.list.d/trueconf.list > /dev/null
    wget -O- https://mirror.trueconf.ru/deb.trueconf.asc | sudo gpg --no-default-keyring --keyring gnupg-ring:/etc/apt/trusted.gpg.d/trueconf.gpg --import
    sudo chmod 644 /etc/apt/trusted.gpg.d/trueconf.gpg
    sudo apt -y update
    sudo apt -y install trueconf

Как обновить?

ВНИМАНИЕ! Если вы ранее устанавливали приложение Труконф из репозитория используя ключ .pub (или видите ошибку проверки публичного ключа), то сначала требуется удалить старый ключ с помощью команды:

sudo rm /etc/apt/trusted.gpg.d/trueconf.gpg

И повторить процедуру установки ключа и обновления приложения:

wget -O- https://mirror.trueconf.ru/deb.trueconf.asc | sudo gpg --no-default-keyring --keyring gnupg-ring:/etc/apt/trusted.gpg.d/trueconf.gpg --import
sudo chmod 644 /etc/apt/trusted.gpg.d/trueconf.gpg
sudo apt -y update
sudo apt -y install trueconf

После первоначальной установки приложения по одному из указанных вариантов, информация об обновлениях будет приходить автоматически.

CentOS, Red Hat Enterprise Linux, Fedora, openSUSE, РЕД ОС, ROSA

Подключение EPEL-репозитория

Перед установкой на CentOS и Red Hat подключите EPEL и CRB репозитории, выполнив команды:

sudo dnf install epel-release
sudo dnf config-manager --set-enabled crb

Как установить?

Нужно запустить команду для скачанного пакета:

  • CentOS (предварительно нужно подключить EPEL-репозиторий):

    sudo dnf install trueconf_client_name.rpm
  • Red Hat Enterprise Linux (предварительно нужно подключить EPEL-репозиторий):

    sudo dnf install trueconf_client_name.rpm
  • Fedora:

    sudo dnf install trueconf_client_name.rpm
  • openSUSE:

    sudo zypper install trueconf_client_name.rpm
  • РЕД ОС:
    sudo yum install trueconf_client_name.rpm
  • ROSA:
    sudo urpmi trueconf_client_name.rpm

где trueconf_client_name.rpm — название скачанного пакета.

После установки приложения, адрес репозитория TrueConf пропишется автоматически.

Альтернативный вариант установки в CentOS, Red Hat Enterprise Linux, Fedora, РЕД ОС, ROSA

  • Создайте файл /etc/yum.repos.d/trueconf.repo с помощью команды (это создаст файл сразу с нужным содержанием):

    • Для CentOS и CentOS Stream (предварительно нужно подключить EPEL-репозиторий):

      echo "[trueconf]
      name=TrueConf Repository
      baseurl=https://mirror.trueconf.ru/centos/\$releasever/\$basearch/release
      enabled=1
      gpgcheck=1
      gpgkey=file:///etc/pki/rpm-gpg/RPM-GPG-KEY-trueconf
      " | sudo tee -a /etc/yum.repos.d/trueconf.repo > /dev/null
    • Для Red Hat Enterprise Linux (предварительно нужно подключить EPEL-репозиторий):

      echo "[trueconf]
      name=TrueConf Repository
      baseurl=https://mirror.trueconf.ru/rhel/\$releasever/\$basearch/release
      enabled=1
      gpgcheck=1
      gpgkey=file:///etc/pki/rpm-gpg/RPM-GPG-KEY-trueconf
      " | sudo tee -a /etc/yum.repos.d/trueconf.repo > /dev/null
    • Для Fedora:

      echo "[trueconf]
      name=TrueConf Repository
      baseurl=https://mirror.trueconf.ru/fedora/\$releasever/\$basearch/release
      enabled=1
      gpgcheck=1
      gpgkey=file:///etc/pki/rpm-gpg/RPM-GPG-KEY-trueconf
      " | sudo tee -a /etc/yum.repos.d/trueconf.repo > /dev/null
    • Для РЕД ОС:
      echo "[trueconf]
      name=TrueConf Repository
      baseurl=https://mirror.trueconf.ru/redos/\$releasever/\$basearch/release
      enabled=1
      gpgcheck=1
      gpgkey=file:///etc/pki/rpm-gpg/RPM-GPG-KEY-trueconf
      " | sudo tee -a /etc/yum.repos.d/trueconf.repo > /dev/null
    • Для ROSA:
      echo "[trueconf]
      name=TrueConf Repository
      baseurl=https://mirror.trueconf.ru/rosa/\$releasever/\$basearch/release
      enabled=1
      gpgcheck=1
      gpgkey=file:///etc/pki/rpm-gpg/RPM-GPG-KEY-trueconf
      " | sudo tee -a /etc/yum.repos.d/trueconf.repo > /dev/null
  • Выполните команды:

    • Для CentOS Stream 9+, Fedora 38+, ROSA 13:

      sudo rpm --import https://mirror.trueconf.ru/rpm-v3.trueconf.pub
      sudo dnf install trueconf
    • Для CentOS версий до Stream 9, Fedora версий до 38, Red Hat Enterprise Linux, РЕД ОС, ROSA 11/12:

      sudo rpm --import https://mirror.trueconf.ru/rpm.trueconf.pub
      sudo dnf install trueconf

Альтернативный вариант установки в openSUSE

  • Создайте файл /etc/zypp/repos.d/trueconf.repo с помощью команды (это создаст файл сразу с нужным содержанием):

    { echo "[trueconf]"
      echo "name=TrueConf Repository"
      echo "enabled=1"
      echo "autorefresh=1"
      echo "baseurl=https://mirror.trueconf.ru/opensuse/\$releasever/\$basearch/release"
      echo "gpgcheck=1"
      echo "type=rpm-md"
      echo "keeppackages=0"
    } | sudo tee -a /etc/zypp/repos.d/trueconf.repo > /dev/null
  • Выполните команды:

    sudo wget https://mirror.trueconf.ru/rpm.trueconf.pub
    sudo rpm --import rpm.trueconf.pub
    sudo zypper refresh
    sudo zypper install trueconf

Как обновить?

После первоначальной установки приложения, информация об обновлениях будет приходить автоматически.

Альт

Как установить?

Выполните команду для скачанного пакета.

sudo apt-get update
sudo apt-get install -y trueconf_client_name.rpm

где trueconf_client_name.rpm — название скачанного пакета

Альтернативный вариант установки

  • Создайте файл /etc/apt/sources.list.d/trueconf.list с помощью команды (это создаст файл сразу с нужным содержанием):

  • Для Альт Рабочая станция 11 64-bit версии:

    echo "rpm https://mirror.trueconf.ru/altlinux/p11/ x86_64 non-free" | sudo tee /etc/apt/sources.list.d/trueconf.list > /dev/null
  • Для Альт Рабочая станция 10 64-bit версии:

    echo "rpm https://mirror.trueconf.ru/altlinux/p10/ x86_64 non-free" | sudo tee /etc/apt/sources.list.d/trueconf.list > /dev/null
  • Для Альт 10 СП 64-bit версии:

    echo "rpm https://mirror.trueconf.ru/altlinux/c10f2/ x86_64 non-free" | sudo tee /etc/apt/sources.list.d/trueconf.list > /dev/null
  • Для Альт Рабочая станция 9 64-bit версии:

    echo "rpm https://mirror.trueconf.ru/altlinux/p9/ x86_64 non-free" | sudo tee /etc/apt/sources.list.d/trueconf.list > /dev/null
  • Для Альт Рабочая 8.2 СП 64-bit версии:

    echo "rpm https://mirror.trueconf.ru/altlinux/c8.2/ x86_64 non-free" | sudo tee /etc/apt/sources.list.d/trueconf.list > /dev/null
  • Для Альт Рабочая станция 8 32-bit версии:

    echo "rpm https://mirror.trueconf.ru/altlinux/p8/ i586 non-free" | sudo tee /etc/apt/sources.list.d/trueconf.list > /dev/null
  • Для Альт Рабочая станция 8 64-bit версии:

    echo "rpm https://mirror.trueconf.ru/altlinux/p8/ x86_64 non-free" | sudo tee /etc/apt/sources.list.d/trueconf.list > /dev/null
  • Последовательно запустите команды:

    sudo apt-get update
    sudo apt-get install -y trueconf

Что делать, если не получается установить Труконф из репозитория на Альт?

В процессе установки из репозитория приложения TrueConf на ОС Альт вы можете увидеть похожую ошибку:

Программа обработки метода /usr/lib64/apt/methods/https не найдена.

Это значит, что в ОС отсутствует вспомогательный пакет apt-https. В этом случае вам надо удалить репозиторий TrueConf и установить данный пакет, и потом уже наше приложение:

  • Удалите файл /etc/apt/sources.list.d/trueconf.list с помощью команды:

    sudo rm -f /etc/apt/sources.list.d/trueconf.list
  • Обновите список репозиториев:

    sudo apt-get update
  • Установите пакет apt-https:

    sudo apt-get install apt-https
  • Добавьте нужный репозиторий и установите приложение TrueConf как показано в предыдущем разделе.

Как обновить?

Дистрибутив ставится поверх текущей версии.

Arch

Как установить?

Доступно только для 64-битных систем:

sudo pacman -U trueconf_client_name.pkg.tar.zst

где trueconf_client_name.pkg.tar.xz — название скачанного пакета

Как обновить?

Дистрибутив ставится поверх текущей версии.

Мы постоянно совершенствуем и улучшаем наши продукты, поэтому при появлении новых версий клиентского приложения пользователь обязательно получит автоматическое уведомление от системы!